import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';

import languages from './languages';
import themes from './themes';
import usePrism from './hooks/usePrism';
import useExternal from './hooks/useExternalContent';
import defaultExternal from './utils/fetchExternal';

Codeblock.propTypes = {
    children: PropTypes.node,
    className: PropTypes.string,
    loadExternal: PropTypes.func,
    language: PropTypes.oneOf(Object.keys(languages)),
    theme: PropTypes.oneOf(Object.keys(themes)),
    component: PropTypes.string,
    innerComponent: PropTypes.string,
    src: PropTypes.string,
    callback: PropTypes.func,
    async: PropTypes.bool
};

export default function Codeblock({
    children,
    className,
    src,
    loadExternal = defaultExternal,
    language = 'javascript',
    theme = 'okaidia',
    component: Outer = 'pre',
    innerComponent: Inner = 'code',
    callback,
    async,
    ...props
}) {
    const ref = React.useRef(null);

    usePrism(ref.current, { language, theme, callback, async });

    let content = children;
    if (src) {
        content = useExternal(src, loadExternal);
    }

    return (
        <Outer
            {...props}
            ref={ref}
            className={cx('Codeblock', className, {
                [`language-${language}`]: language
            })}
        >
            <Inner>{content}</Inner>
        </Outer>
    );
}
